# This is a BitKeeper generated diff -Nru style patch.
#
# ChangeSet
#   2005/03/18 16:27:13-05:00 len.brown@intel.com 
#   [ACPI] Suspend to RAM fix
#   
#   Free some RAM before entering S3 so that upon
#   resume we can be sure early allocations will succeed.
#   
#   http://bugzilla.kernel.org/show_bug.cgi?id=3469
#   
#   Signed-off-by: David Shaohua Li <shaohua.li@intel.com>
#   Signed-off-by: Len Brown <len.brown@intel.com>
# 
# kernel/power/main.c
#   2005/03/02 22:23:28-05:00 len.brown@intel.com +14 -0
#   free RAM before entering S3
# 
Index: linux-2.6.13/kernel/power/main.c
===================================================================
--- linux-2.6.13.orig/kernel/power/main.c	2005-07-10 01:04:12.000000000 -0400
+++ linux-2.6.13/kernel/power/main.c	2005-07-10 01:04:21.000000000 -0400
@@ -19,6 +19,9 @@
 
 #include "power.h"
 
+/*This is just an arbitrary number */
+#define FREE_PAGE_NUMBER (100)
+
 DECLARE_MUTEX(pm_sem);
 
 struct pm_ops * pm_ops = NULL;
@@ -49,6 +52,7 @@
 static int suspend_prepare(suspend_state_t state)
 {
 	int error = 0;
+	unsigned int free_pages;
 
 	if (!pm_ops || !pm_ops->enter)
 		return -EPERM;
@@ -67,6 +71,16 @@
 		goto Thaw;
 	}
 
+	if ((free_pages = nr_free_pages()) < FREE_PAGE_NUMBER) {
+		pr_debug("PM: free some memory\n");
+		shrink_all_memory(FREE_PAGE_NUMBER - free_pages);
+		if (nr_free_pages() < FREE_PAGE_NUMBER) {
+			error = -ENOMEM;
+			printk(KERN_ERR "PM: No enough memory\n");
+			goto Thaw;
+		}
+	}
+
 	if (pm_ops->prepare) {
 		if ((error = pm_ops->prepare(state)))
 			goto Thaw;
